@@ -1,9 +1,12 @@
-# nextcloud_activites.py
+"""
+handle activities
+"""
 
 from .nextcloud_data import NextcloudData
 from .translations import TRANSLATIONS
 from .nextcloud_requests import NextcloudRequests
 
+
 class NextcloudActivities:
     """
     A class to handle Nextcloud activities.
@@ -24,7 +27,7 @@ class NextcloudActivities:
         """
         endpoint = "/ocs/v2.php/cloud/activity"
         response = self.nextcloud_requests.send_request(endpoint)
-        
+
         return response['ocs']['data']
 
     def search_last_activities(self, activity):
@@ -34,8 +37,7 @@ class NextcloudActivities:
         :param activities: he activity to search for, i.e. to-do, event, shared, deleted, created, changed
         :return: A list of filtered activities.
         """
-        nextcloud = NextcloudActivities(self.base_url, self.username, self.password)
-        response = nextcloud.get_last_activities()
+        response = self.get_last_activities()
         filtered_data = []
         for item in response:
             subject = item['subject']
@@ -45,13 +47,13 @@ class NextcloudActivities:
 
         return filtered_data
 
-if __name__ == "__main__":
-    data = read_nextcloud_data()
 
+if __name__ == "__main__":
+    ncdata = NextcloudData
+    data = ncdata.read_nextcloud_data()
     for key, value in data.items():
         locals()[key] = value
 
-
     nextcloud = NextcloudActivities(NEXTCLOUD_URL, USERNAME, PASSWORD)
     last_activities = nextcloud.search_last_activities(activity="event")
     print(last_activities)
