@@ -7,5 +7,4 @@ permissions_map = {
     16: "Can publish audio stream",
     32: "Can publish video stream",
     64: "Can publish screen sharing stream",
-    128: "Can post chat message, share items and do reactions"
-}
\ No newline at end of file
+    128: "Can post chat message, share items and do reactions"}
